use std::net::SocketAddr;

use tonic::transport::Server;

use self::gen::{greeter_server, HelloReply, HelloRequest};

mod gen {
    tonic::include_proto!("flux_releaser");
}

#[derive(Debug, Default)]
pub struct FluxReleaserGrpc {}
#[tonic::async_trait]
impl greeter_server::Greeter for FluxReleaserGrpc {
    async fn say_hello(
        &self,
        request: tonic::Request<HelloRequest>,
    ) -> std::result::Result<tonic::Response<HelloReply>, tonic::Status> {
        Ok(tonic::Response::new(HelloReply {
            message: "something".into(),
        }))
    }
}

pub async fn tonic_serve(host: SocketAddr) -> anyhow::Result<()> {
    tracing::info!("grpc listening on: {}", host);
    Server::builder()
        .add_service(greeter_server::GreeterServer::new(
            FluxReleaserGrpc::default(),
        ))
        .serve(host)
        .await?;

    Ok(())
}
